peek method
Peek at the upcoming count pieces without consuming them.
Implementation
List<TetrominoType> peek(int count) {
while (_bag.length < count) {
_refill();
}
return _bag.take(count).toList();
}
Peek at the upcoming count pieces without consuming them.
List<TetrominoType> peek(int count) {
while (_bag.length < count) {
_refill();
}
return _bag.take(count).toList();
}