RotationSystem class

Implements the Tetris Guideline Super Rotation System (SRS).

Constructors

RotationSystem(CollisionSystem _collision)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rotateCCW(Tetromino piece, BoardState board) Tetromino?
Attempts counter-clockwise rotation with SRS wall-kick tests.
rotateCW(Tetromino piece, BoardState board) Tetromino?
Attempts clockwise rotation with SRS wall-kick tests. Returns the rotated piece or null if no valid kick found.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited