TetrisGame class

Inheritance

Constructors

TetrisGame({int boardRows = 20, int boardCols = 10, int nextQueueSize = 5, void onScoreChanged(int score)?, void onGameOver()?, void onLevelUp(int score)?, void onLinesCleared(int score)?})

Properties

boardCols int
final
boardRows int
final
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
nextQueueSize int
final
onGameOver ↔ void Function()?
getter/setter pair
onLevelUp ↔ void Function(int score)?
getter/setter pair
onLinesCleared ↔ void Function(int score)?
getter/setter pair
onScoreChanged ↔ void Function(int score)?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state GameState
no setter
statistics TetrisStatistics
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
override
hardDrop() → void
holdPiece() → void
loadFromJson(Map<String, dynamic> json) → void
moveLeft() → void
moveRight() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
pause() → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
restart() → void
resume() → void
rotateCCW() → void
rotateCW() → void
softDrop() → void
start() → void
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited