gravityCurve property
Optional custom gravity: the delay between automatic drops at a given level. Defaults to LevelState.gravityMs.
Implementation
final Duration Function(int level)? gravityCurve;
Optional custom gravity: the delay between automatic drops at a given level. Defaults to LevelState.gravityMs.
final Duration Function(int level)? gravityCurve;