moveLeft method
void
moveLeft()
Moves the active piece one column left, if possible.
Implementation
void moveLeft() => _tryMove(-1, 'moveLeft');
Moves the active piece one column left, if possible.
void moveLeft() => _tryMove(-1, 'moveLeft');