moveRight method
void
moveRight()
Moves the active piece one column right, if possible.
Implementation
void moveRight() => _tryMove(1, 'moveRight');
Moves the active piece one column right, if possible.
void moveRight() => _tryMove(1, 'moveRight');