seed property
int
get
seed
Seed of the piece randomizer for the current game. Starting a game with the same seed produces the same piece sequence.
Implementation
int get seed => _seed;
Seed of the piece randomizer for the current game. Starting a game with the same seed produces the same piece sequence.
int get seed => _seed;