isEmpty property
bool
get
isEmpty
True when no cell on the board is filled (e.g. after a perfect clear).
Implementation
bool get isEmpty => grid.every((row) => row.every((c) => !c.filled));
True when no cell on the board is filled (e.g. after a perfect clear).
bool get isEmpty => grid.every((row) => row.every((c) => !c.filled));