Cell class

Represents a single cell on the Tetris board.

Constructors

Cell({bool filled = false, TetrominoType? type})
const
Cell.empty()
const
Cell.fromJson(Map<String, dynamic> json)
factory

Properties

filled bool
Whether this cell is occupied.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type TetrominoType?
Which tetromino type filled this cell (null if empty).
final

Methods

copyWith({bool? filled, TetrominoType? type}) Cell
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override