Position class

A 2D integer coordinate on the Tetris board.

Constructors

Position(int row, int col)
const
Position.fromJson(Map<String, dynamic> json)
factory

Properties

col → int
final
hashCode → int
The hash code for this object.
no setteroverride
row → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? row, int? col}) → Position
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator +(Position other) → Position
operator -(Position other) → Position
operator ==(Object other) → bool
The equality operator.
override