ScoreState class

Tracks the current scoring state.

Constructors

ScoreState({int score = 0, int combo = 0, bool backToBack = false})
const
ScoreState.fromJson(Map<String, dynamic> json)
factory

Properties

backToBack bool
final
combo int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score int
final

Methods

copyWith({int? score, int? combo, bool? backToBack}) ScoreState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited