TetrisEventType enum

The kind of TetrisEvent emitted by a game.

Inheritance
Available extensions

Values

started → const TetrisEventType
paused → const TetrisEventType
resumed → const TetrisEventType
moved → const TetrisEventType
rotated → const TetrisEventType
softDropped → const TetrisEventType
hardDropped → const TetrisEventType
held → const TetrisEventType
locked → const TetrisEventType

A piece locked onto the board (always emitted, even with no line clear).

linesCleared → const TetrisEventType

One or more lines were cleared. See TetrisEvent.lines, TetrisEvent.tSpin, TetrisEvent.perfectClear and TetrisEvent.backToBack.

tSpin → const TetrisEventType

A T-Spin was performed without clearing any lines.

levelUp → const TetrisEventType
gameOver → const TetrisEventType

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<TetrisEventType>
A constant List of the values in this enum, in order of their declaration.