base property
Theme the palettes are applied on top of; supplies text styles, border width, radius and any colors a palette leaves out.
Implementation
final TetrisTheme base;
Theme the palettes are applied on top of; supplies text styles, border width, radius and any colors a palette leaves out.
final TetrisTheme base;