TetrisAnimationController class

Holds references to Flutter AnimationControllers used for Tetris effects. Pass an instance to TetrisBoard to hook into piece lock, line clear, etc.

Constructors

TetrisAnimationController({void onPieceLock()?, void onLineClear(int lines)?, void onGameOver()?, void onLevelUp(int lines)?, void onHardDrop()?})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
onGameOver → void Function()?
final
onHardDrop → void Function()?
final
onLevelUp → void Function(int lines)?
final
onLineClear → void Function(int lines)?
final
onPieceLock → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited