TetrisAnimationController class
Callbacks for Tetris effects.
This class was never wired into the engine. Use TetrisGame.events,
which reports piece locks, line clears, level ups and more.
- Annotations
-
- @Deprecated('Not connected to the engine. Listen to TetrisGame.events instead. ' 'Will be removed in 2.0.0.')
Constructors
- TetrisAnimationController({void onPieceLock()?, void onLineClear(int lines)?, void onGameOver()?, void onLevelUp(int lines)?, void onHardDrop()?})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onGameOver → void Function()?
-
final
- onHardDrop → void Function()?
-
final
- onLevelUp → void Function(int lines)?
-
final
- onLineClear → void Function(int lines)?
-
final
- onPieceLock → void Function()?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited