InputController class
Maps high-level action strings to game engine calls.
Supported actions: moveLeft, moveRight, softDrop, hardDrop,
rotCW, rotCCW, hold, pause (toggles pause/resume), resume,
and the clock actions gravity and lock used by replays.
Constructors
- InputController(TetrisGame game)
Properties
- game → TetrisGame
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispatch(
String action) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited