BoardManager class
Manages board mutations (locking pieces, clearing lines).
Constructors
- BoardManager(CollisionSystem _collision)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isBlockOut(
BoardState board, Tetromino piece) → bool -
Returns true if spawning
pieceonboardimmediately collides (block-out game over condition). -
lockAndClear(
BoardState board, Tetromino piece) → (BoardState, int) -
Locks
pieceontoboardand clears completed lines. Returns (newBoard, linesCleared). -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited