LevelSystem class

Manages level progression.

Constructors

LevelSystem({int linesPerLevel = 10})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
linesPerLevel → int
Number of cleared lines required to advance one level.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

initialState({int startLevel = 1}) → LevelState
The level state a new game starts with.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onLinesCleared(LevelState state, int linesCleared) → LevelState
Returns updated LevelState after clearing linesCleared lines.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited