ScoringSystem class

Tetris Guideline scoring.

Constructors

ScoringSystem()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onHardDrop(ScoreState state, int cells) ScoreState
onLinesCleared(ScoreState state, int linesCleared, int level) ScoreState
Returns a new ScoreState after clearing linesCleared lines. level is used for point multipliers.
onSoftDrop(ScoreState state, int cells) ScoreState
Points for soft drop (1 per cell) and hard drop (2 per cell).
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited