TetrisKeyboardHandler class
Maps keyboard LogicalKeyboardKeys to game actions. Wire this to a Focus or RawKeyboardListener widget.
Constructors
-
TetrisKeyboardHandler(InputController input, {Map<
LogicalKeyboardKey, String> ? keyMap})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- input → InputController
-
final
-
keyMap
→ Map<
LogicalKeyboardKey, String> -
Customizable key mapping.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
handleKeyEvent(
KeyEvent event) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited