LevelState class

Tracks the current level and line-count state.

Constructors

LevelState({int level = 1, int linesCleared = 0, int linesUntilNextLevel = 10})
const
LevelState.fromJson(Map<String, dynamic> json)
factory

Properties

gravityMs int
Gravity delay in milliseconds for the current level.
no setter
hashCode int
The hash code for this object.
no setterinherited
level int
final
linesCleared int
final
linesUntilNextLevel int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? level, int? linesCleared, int? linesUntilNextLevel}) LevelState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited